@@ -23,17 +23,7 @@ class ReferenceField(BaseField):
         return value._id is not None
 
     def to_son(self, value):
-        return {
-            '__module__': value.__module__,
-            '__class__': value.__class__.__name__,
-            '__id__': str(value._id),
-            '__loaded__': False
-        }
+        return value._id
 
     def from_son(self, value):
-        return {
-            '__module__': value['__module__'],
-            '__class__': value['__class__'],
-            '__id__': value['__id__'],
-            '__loaded__': False
-        }
+        return value
